==> zio-aws-mgn_2.12-5.17.212.1-sources.jar: zio/aws/mgn/model/UpdateLaunchConfigurationRequest.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.mgn.model.primitives.{SourceServerID, SmallBoundedString}
import scala.jdk.CollectionConverters._
final case class UpdateLaunchConfigurationRequest(
    bootMode: Optional[zio.aws.mgn.model.BootMode] = Optional.Absent,
    copyPrivateIp: Optional[Boolean] = Optional.Absent,
    copyTags: Optional[Boolean] = Optional.Absent,
    launchDisposition: Optional[zio.aws.mgn.model.LaunchDisposition] =
      Optional.Absent,
    licensing: Optional[zio.aws.mgn.model.Licensing] = Optional.Absent,
    name: Optional[SmallBoundedString] = Optional.Absent,
    sourceServerID: SourceServerID,
    targetInstanceTypeRightSizingMethod: Optional[
      zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest = {
    import UpdateLaunchConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
      .builder()
      .optionallyWith(bootMode.map(value => value.unwrap))(_.bootMode)
      .optionallyWith(copyPrivateIp.map(value => value: java.lang.Boolean))(
        _.copyPrivateIp
      )
      .optionallyWith(copyTags.map(value => value: java.lang.Boolean))(
        _.copyTags
      )
      .optionallyWith(launchDisposition.map(value => value.unwrap))(
        _.launchDisposition
      )
      .optionallyWith(licensing.map(value => value.buildAwsValue()))(
        _.licensing
      )
      .optionallyWith(
        name.map(value => SmallBoundedString.unwrap(value): java.lang.String)
      )(_.name)
      .sourceServerID(SourceServerID.unwrap(sourceServerID): java.lang.String)
      .optionallyWith(
        targetInstanceTypeRightSizingMethod.map(value => value.unwrap)
      )(_.targetInstanceTypeRightSizingMethod)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.UpdateLaunchConfigurationRequest.ReadOnly =
    zio.aws.mgn.model.UpdateLaunchConfigurationRequest.wrap(buildAwsValue())
}
object UpdateLaunchConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.UpdateLaunchConfigurationRequest =
      zio.aws.mgn.model.UpdateLaunchConfigurationRequest(
        bootMode.map(value => value),
        copyPrivateIp.map(value => value),
        copyTags.map(value => value),
        launchDisposition.map(value => value),
        licensing.map(value => value.asEditable),
        name.map(value => value),
        sourceServerID,
        targetInstanceTypeRightSizingMethod.map(value => value)
      )
    def bootMode: Optional[zio.aws.mgn.model.BootMode]
    def copyPrivateIp: Optional[Boolean]
    def copyTags: Optional[Boolean]
    def launchDisposition: Optional[zio.aws.mgn.model.LaunchDisposition]
    def licensing: Optional[zio.aws.mgn.model.Licensing.ReadOnly]
    def name: Optional[SmallBoundedString]
    def sourceServerID: SourceServerID
    def targetInstanceTypeRightSizingMethod
        : Optional[zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod]
    def getBootMode: ZIO[Any, AwsError, zio.aws.mgn.model.BootMode] =
      AwsError.unwrapOptionField("bootMode", bootMode)
    def getCopyPrivateIp: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("copyPrivateIp", copyPrivateIp)
    def getCopyTags: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("copyTags", copyTags)
    def getLaunchDisposition
        : ZIO[Any, AwsError, zio.aws.mgn.model.LaunchDisposition] =
      AwsError.unwrapOptionField("launchDisposition", launchDisposition)
    def getLicensing: ZIO[Any, AwsError, zio.aws.mgn.model.Licensing.ReadOnly] =
      AwsError.unwrapOptionField("licensing", licensing)
    def getName: ZIO[Any, AwsError, SmallBoundedString] =
      AwsError.unwrapOptionField("name", name)
    def getSourceServerID: ZIO[Any, Nothing, SourceServerID] =
      ZIO.succeed(sourceServerID)
    def getTargetInstanceTypeRightSizingMethod: ZIO[
      Any,
      AwsError,
      zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod
    ] = AwsError.unwrapOptionField(
      "targetInstanceTypeRightSizingMethod",
      targetInstanceTypeRightSizingMethod
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
  ) extends zio.aws.mgn.model.UpdateLaunchConfigurationRequest.ReadOnly {
    override val bootMode: Optional[zio.aws.mgn.model.BootMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.bootMode())
        .map(value => zio.aws.mgn.model.BootMode.wrap(value))
    override val copyPrivateIp: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.copyPrivateIp())
      .map(value => value: Boolean)
    override val copyTags: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.copyTags())
      .map(value => value: Boolean)
    override val launchDisposition
        : Optional[zio.aws.mgn.model.LaunchDisposition] = zio.aws.core.internal
      .optionalFromNullable(impl.launchDisposition())
      .map(value => zio.aws.mgn.model.LaunchDisposition.wrap(value))
    override val licensing: Optional[zio.aws.mgn.model.Licensing.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.licensing())
        .map(value => zio.aws.mgn.model.Licensing.wrap(value))
    override val name: Optional[SmallBoundedString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.mgn.model.primitives.SmallBoundedString(value))
    override val sourceServerID: SourceServerID =
      zio.aws.mgn.model.primitives.SourceServerID(impl.sourceServerID())
    override val targetInstanceTypeRightSizingMethod
        : Optional[zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetInstanceTypeRightSizingMethod())
        .map(value =>
          zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
  ): zio.aws.mgn.model.UpdateLaunchConfigurationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mgn_2.13-5.17.130.8-sources.jar: zio/aws/mgn/model/UpdateLaunchConfigurationRequest.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mgn.model.primitives.{SourceServerID, SmallBoundedString}
import scala.jdk.CollectionConverters._
final case class UpdateLaunchConfigurationRequest(
    copyPrivateIp: Option[Boolean] = None,
    copyTags: Option[Boolean] = None,
    launchDisposition: Option[zio.aws.mgn.model.LaunchDisposition] = None,
    licensing: Option[zio.aws.mgn.model.Licensing] = None,
    name: Option[SmallBoundedString] = None,
    sourceServerID: SourceServerID,
    targetInstanceTypeRightSizingMethod: Option[
      zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest = {
    import UpdateLaunchConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
      .builder()
      .optionallyWith(copyPrivateIp.map(value => value: java.lang.Boolean))(
        _.copyPrivateIp
      )
      .optionallyWith(copyTags.map(value => value: java.lang.Boolean))(
        _.copyTags
      )
      .optionallyWith(launchDisposition.map(value => value.unwrap))(
        _.launchDisposition
      )
      .optionallyWith(licensing.map(value => value.buildAwsValue()))(
        _.licensing
      )
      .optionallyWith(
        name.map(value => SmallBoundedString.unwrap(value): java.lang.String)
      )(_.name)
      .sourceServerID(SourceServerID.unwrap(sourceServerID): java.lang.String)
      .optionallyWith(
        targetInstanceTypeRightSizingMethod.map(value => value.unwrap)
      )(_.targetInstanceTypeRightSizingMethod)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.UpdateLaunchConfigurationRequest.ReadOnly =
    zio.aws.mgn.model.UpdateLaunchConfigurationRequest.wrap(buildAwsValue())
}
object UpdateLaunchConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.UpdateLaunchConfigurationRequest =
      zio.aws.mgn.model.UpdateLaunchConfigurationRequest(
        copyPrivateIp.map(value => value),
        copyTags.map(value => value),
        launchDisposition.map(value => value),
        licensing.map(value => value.asEditable),
        name.map(value => value),
        sourceServerID,
        targetInstanceTypeRightSizingMethod.map(value => value)
      )
    def copyPrivateIp: Option[Boolean]
    def copyTags: Option[Boolean]
    def launchDisposition: Option[zio.aws.mgn.model.LaunchDisposition]
    def licensing: Option[zio.aws.mgn.model.Licensing.ReadOnly]
    def name: Option[SmallBoundedString]
    def sourceServerID: SourceServerID
    def targetInstanceTypeRightSizingMethod
        : Option[zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod]
    def getCopyPrivateIp: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("copyPrivateIp", copyPrivateIp)
    def getCopyTags: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("copyTags", copyTags)
    def getLaunchDisposition
        : ZIO[Any, AwsError, zio.aws.mgn.model.LaunchDisposition] =
      AwsError.unwrapOptionField("launchDisposition", launchDisposition)
    def getLicensing: ZIO[Any, AwsError, zio.aws.mgn.model.Licensing.ReadOnly] =
      AwsError.unwrapOptionField("licensing", licensing)
    def getName: ZIO[Any, AwsError, SmallBoundedString] =
      AwsError.unwrapOptionField("name", name)
    def getSourceServerID: ZIO[Any, Nothing, SourceServerID] =
      ZIO.succeed(sourceServerID)
    def getTargetInstanceTypeRightSizingMethod: ZIO[
      Any,
      AwsError,
      zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod
    ] = AwsError.unwrapOptionField(
      "targetInstanceTypeRightSizingMethod",
      targetInstanceTypeRightSizingMethod
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
  ) extends zio.aws.mgn.model.UpdateLaunchConfigurationRequest.ReadOnly {
    override val copyPrivateIp: Option[Boolean] =
      scala.Option(impl.copyPrivateIp()).map(value => value: Boolean)
    override val copyTags: Option[Boolean] =
      scala.Option(impl.copyTags()).map(value => value: Boolean)
    override val launchDisposition
        : Option[zio.aws.mgn.model.LaunchDisposition] = scala
      .Option(impl.launchDisposition())
      .map(value => zio.aws.mgn.model.LaunchDisposition.wrap(value))
    override val licensing: Option[zio.aws.mgn.model.Licensing.ReadOnly] = scala
      .Option(impl.licensing())
      .map(value => zio.aws.mgn.model.Licensing.wrap(value))
    override val name: Option[SmallBoundedString] = scala
      .Option(impl.name())
      .map(value => zio.aws.mgn.model.primitives.SmallBoundedString(value))
    override val sourceServerID: SourceServerID =
      zio.aws.mgn.model.primitives.SourceServerID(impl.sourceServerID())
    override val targetInstanceTypeRightSizingMethod
        : Option[zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod] = scala
      .Option(impl.targetInstanceTypeRightSizingMethod())
      .map(value =>
        zio.aws.mgn.model.TargetInstanceTypeRightSizingMethod.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.UpdateLaunchConfigurationRequest
  ): zio.aws.mgn.model.UpdateLaunchConfigurationRequest.ReadOnly = new Wrapper(
    impl
  )
}
